use std::path::Path;

use serde::Serialize;

use crate::config::Config;
use crate::error::CustomError;
use crate::intermediate::IFootnoteReference;

#[derive(Debug, Serialize)]
#[serde(tag = "type")]
#[serde(rename = "footnote_reference")]
pub(crate) struct RenderFootnoteReference {
    reference_id: String,
    definition_link: String,
    label: String,
}

impl RenderFootnoteReference {
    pub(crate) fn new(
        _config: &Config,
        _output_directory: &Path,
        _output_file: &Path,
        original: &IFootnoteReference,
    ) -> Result<RenderFootnoteReference, CustomError> {
        Ok(RenderFootnoteReference {
            reference_id: original.get_reference_id(),
            definition_link: format!("#{}", original.get_definition_id()),
            label: original.get_display_label(),
        })
    }
}
